==> libunwind_1.2.1.orig.tar.gz: libunwind-1.2.1/src/ppc64/get_func_addr.c <==
/* libunwind - a platform-independent unwind library
   Copyright (C) 2006-2007 IBM
   Contributed by
     Corey Ashford <cjashfor@us.ibm.com>
     Jose Flavio Aguilar Paulino <jflavio@br.ibm.com> <joseflavio@gmail.com>

This file is part of libunwind.

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */

#include "unwind_i.h"

int
tdep_get_func_addr (unw_addr_space_t as, unw_word_t addr,
                    unw_word_t *entry_point)
{
  if (as->abi == UNW_PPC64_ABI_ELFv1)
    {
      unw_accessors_t *a;
      int ret;

      a = unw_get_accessors (as);
      /* Entry-point is stored in the 1st word of the function descriptor.
         In case that changes in the future, we'd have to update the line
         below and read the word at addr + offset: */
      ret = (*a->access_mem) (as, addr, entry_point, 0, NULL);
      if (ret < 0)
        return ret;
    }
  else
    *entry_point = addr;

  return 0;
}

==> libunwind_1.8.1.orig.tar.gz: libunwind-1.8.1/src/ppc64/get_func_addr.c <==
/* libunwind - a platform-independent unwind library
   Copyright (C) 2006-2007 IBM
   Contributed by
     Corey Ashford <cjashfor@us.ibm.com>
     Jose Flavio Aguilar Paulino <jflavio@br.ibm.com> <joseflavio@gmail.com>

This file is part of libunwind.

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */

#include "unwind_i.h"

int
tdep_get_func_addr (unw_addr_space_t as, unw_word_t addr,
                    unw_word_t *entry_point)
{
  if (as->abi == UNW_PPC64_ABI_ELFv1)
    {
      unw_accessors_t *a;
      int ret;

      a = unw_get_accessors_int (as);
      /* Entry-point is stored in the 1st word of the function descriptor.
         In case that changes in the future, we'd have to update the line
         below and read the word at addr + offset: */
      ret = (*a->access_mem) (as, addr, entry_point, 0, NULL);
      if (ret < 0)
        return ret;
    }
  else
    *entry_point = addr;

  return 0;
}
